@@ -31,6 +31,8 @@ sub new {
 
 	      'heads'=>[],
 	      'problems'=>{},
+	      'numeric.content'=>{},
+	      'simple.content'=>{},
 	      'err'=>[0,0],
 	  };
 
@@ -87,6 +89,7 @@ sub load {
 	      s/\#.*//;
 	      next NOM if(/^\s*$/);
 	      if(!@heads) {
+		  my $keep=0;
 		  if($sep) {
 
 		      my $entetes=$_;
@@ -105,11 +108,16 @@ sub load {
 		      }
 
 		      @heads=map { reduit($_) } split(/$sep/,$entetes,-1);
-		      debug "KEYS: ".join(", ",@heads);
-		      next NOM;
 		  } else {
 		      @heads='nom';
+		      $keep=1;
 		  }
+		  for(@heads) {
+		      $self->{'numeric.content'}->{$_}=0;
+		      $self->{'simple.content'}->{$_}=0;
+		  }
+		  debug "KEYS: ".join(", ",@heads);
+		  next NOM if(!$keep);
 	      }
 	      s/^\s+//;
 	      s/\s+$//;
@@ -128,6 +136,10 @@ sub load {
 		  for(0..$#l) {
 		      $nom->{$heads[$_]}=$l[$_];
 		      $data{$heads[$_]}->{$l[$_]}++;
+		      $self->{'numeric.content'}->{$heads[$_]} ++
+			  if($l[$_] =~ /^[ 0-9.+-]*$/i);
+		      $self->{'simple.content'}->{$heads[$_]} ++
+			  if($l[$_] =~ /^[ a-z0-9.+-]*$/i);
 		  }
 		  $nom->{'_LINE_'}=$line;
 		  push @{$self->{'noms'}},$nom;
@@ -221,7 +233,12 @@ sub heads { # entetes
 
 sub keys { # entetes qui peuvent servir de cle unique
     my ($self)=@_;
-    return(@{$self->{'keys'}});
+    return(sort { $self->{'simple.content'}->{$b} <=>
+		      $self->{'simple.content'}->{$a}
+		  || $self->{'numeric.content'}->{$b} <=>
+		      $self->{'numeric.content'}->{$a}
+		  || $a cmp $b }
+		  @{$self->{'keys'}});
 }
 
 sub liste {
