@@ -60,7 +60,8 @@ my $dpi=300;
 my $calage='';
 
 my $moteur_latex='latex';
-
+my @moteur_args=();
+my $moteur_topdf='';
 my $prefix='';
 
 my $debug='';
@@ -77,6 +78,8 @@ my $out_corrige='';
 
 my $moteur_raster='poppler';
 
+my $jobname="amc-compiled";
+
 my $encodage_interne='UTF-8';
 
 GetOptions("mode=s"=>\$mode,
@@ -102,6 +105,16 @@ set_debug($debug);
 
 debug("AMC-prepare / DEBUG") if($debug);
 
+if($moteur_latex =~ /([^ ]+)\s+(.*)/) {
+    $moteur_latex=$1;
+    @moteur_args=split(/ +/,$2);
+}
+
+if($moteur_latex =~ /(.*)\+(.*)/) {
+    $moteur_latex=$1;
+    $moteur_topdf=$2;
+}
+
 $queue=AMC::Queue::new('max.procs',$n_procs);
 
 my $avance=AMC::Gui::Avancement::new($progress,'id'=>$progress_id);
@@ -220,9 +233,9 @@ sub execute {
     my $format='';
 
     for my $ext (qw/pdf dvi ps/) {
-	if(-f $f_base.".$ext") {
+	if(-f "$jobname.$ext") {
 	    debug "Removing old $ext";
-	    unlink($f_base.".$ext");
+	    unlink("$jobname.$ext");
 	}
     }
 
@@ -263,14 +276,26 @@ sub execute {
     debug "Output format: $format\n";
 
     if($format eq 'dvi') {
-	if(-f $f_base.".dvi") {
-	    if(commande_accessible('dvipdfm')) {
-		debug "Converting DVI to PDF with dvipdfm...";
-		system("dvipdfm","-o",$f_base.".pdf",$f_base.".dvi");
-		print "ERROR dvipdfm: $?\n" if($?);
+	if(-f "$jobname.dvi") {
+	    $moteur_topdf='dvipdfm'
+		if(!$moteur_topdf);
+	    if(!commande_accessible($moteur_topdf)) {
+		debug_and_stderr
+		    "WARNING: command $moteur_topdf not available";
+		$moteur_topdf=choose_command('dvipdfmx','dvipdfm','xdvipdfmx',
+					     'dvipdf');
+	    }
+	    if($moteur_topdf) {
+		debug "Converting DVI to PDF with $moteur_topdf ...";
+		if($moteur_topdf eq 'dvipdf') {
+		    system($moteur_topdf,"$jobname.dvi","$jobname.pdf");
+		} else {
+		    system($moteur_topdf,"-o","$jobname.pdf","$jobname.dvi");
+		}
+		debug_and_stderr "ERROR $moteur_topdf: $?" if($?);
 	    } else {
-		print "ERROR: I can't find dvipdfm command !";
-		debug "ERROR: I can't find dvipdfm command !";
+		debug_and_stderr
+		    "ERROR: I can't find dvipdf/dvipdfm/xdvipdfmx command !";
 	    }
 	} else {
 	    debug "No DVI";
@@ -319,6 +344,8 @@ sub latex_cmd {
     $o{'AMCNombreCopies'}=$nombre_copies if($nombre_copies>0);
 
     return($moteur_latex,
+	   "--jobname=".$jobname,
+	   @moteur_args,
 	   "\\nonstopmode"
 	   .join('',map { "\\def\\".$_."{".$o{$_}."}"; } (keys %o) )
 	   ." \\input{\"$f_tex\"}");
@@ -337,7 +364,7 @@ if($mode =~ /k/) {
     check_moteur();
 
     execute('command'=>[latex_cmd(qw/NoWatermarkExterne 1 NoHyperRef 1 CorrigeIndivExterne 1/)]);
-    transfere("$f_base.pdf",($out_corrige ? $out_corrige : $prefix."corrige.pdf"));
+    transfere("$jobname.pdf",($out_corrige ? $out_corrige : $prefix."corrige.pdf"));
     give_latex_errors(__"individual solution");
 }
 
@@ -363,13 +390,13 @@ if($mode =~ /s/) {
     # 1) sujet et calage
 
     execute('command'=>[latex_cmd(%opts,'SujetExterne'=>1)]);
-    analyse_amclog("$f_base.amc");
-    transfere("$f_base.pdf",$out_sujet);
+    analyse_amclog("$jobname.amc");
+    transfere("$jobname.pdf",$out_sujet);
     give_latex_errors(__"question sheet");
 
     exit(1) if($a_erreurs>0);
 
-    transfere("$f_base.xy",$out_calage);
+    transfere("$jobname.xy",$out_calage);
 
     # transmission des variables
 
@@ -381,7 +408,7 @@ if($mode =~ /s/) {
     # 2) corrige
 
     execute('command'=>[latex_cmd(%opts,'CorrigeExterne'=>1)]);
-    transfere("$f_base.pdf",$out_corrige);
+    transfere("$jobname.pdf",$out_corrige);
     give_latex_errors(__"solution");
 }
 
@@ -488,7 +515,7 @@ if($mode =~ /b/) {
 
     execute('command'=>[latex_cmd(qw/CalibrationExterne 1 NoHyperRef 1/)],
 	    'once'=>1);
-    open(AMCLOG,"$f_base.amc") or die "Unable to open $f_base.amc : $!";
+    open(AMCLOG,"$jobname.amc") or die "Unable to open $jobname.amc : $!";
     while(<AMCLOG>) {
 	debug($_);
 	if(/AUTOQCM\[TOTAL=([\s0-9]+)\]/) { 
